"""Test's routes definition."""

routes = [
    {'name': 'index', 'pattern': '/'},
    {'name': 'secret', 'pattern': '/secret'},
    {'name': 'very_secret', 'pattern': '/secret/very'},
]
